@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1998 Janne Lf <jlof@mail.student.oulu.fi>
+ * Copyright (C) 1998 Janne Löf <jlof@mail.student.oulu.fi>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,14 +19,25 @@
 #ifndef __GDK_GL_H__
 #define __GDK_GL_H__
 
-#include <gdk/gdk.h>
+#include <glib.h>
 
-
-#ifdef __cplusplus
-extern "C" {
+#ifdef G_OS_WIN32
+ /* The GL/gl.h on Windows requires you to include <windows.h>
+  * anyway, so we might as well include it here.
+  */
+ #include <windows.h>
 #endif
 
+#include <gdk/gdk.h>
 
+G_BEGIN_DECLS
+
+/*
+ * These definitions are duplicated from GL/glx.h that comes with Mesa.
+ * I don't want every program to include GL/glx.h because GtkGLArea
+ * supports lecacy systems like Windows. You can still use GLX_xxxx
+ * attributes with these, but then you lose portability.
+ */
 enum _GDK_GL_CONFIGS {
         GDK_GL_NONE             = 0,
 	GDK_GL_USE_GL		= 1,
@@ -58,19 +69,26 @@ enum _GDK_GL_CONFIGS {
 };
 
 
+#define GDK_TYPE_GL_CONTEXT            (gdk_gl_context_get_type())
+#define GDK_GL_CONTEXT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDK_TYPE_GL_CONTEXT, GdkGLContext))
+#define GDK_GL_CONTEXT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDK_TYPE_GL_CONTEXT, GdkGLContextClass))
+#define GDK_IS_GL_CONTEXT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDK_TYPE_GL_CONTEXT))
+#define GDK_IS_GL_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_GL_CONTEXT))
+#define GDK_GL_CONTEXT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_GL_CONTEXT, GdkGLContext))
+
 typedef struct _GdkGLContext GdkGLContext;
 
 
 gint          gdk_gl_query(void);
+gchar        *gdk_gl_get_info(void);
 
-GdkVisual    *gdk_gl_choose_visual(int *attrList);
+GdkVisual    *gdk_gl_choose_visual(int *attrlist);
 int           gdk_gl_get_config(GdkVisual *visual, int attrib);
 
+GType         gdk_gl_context_get_type(void);
 GdkGLContext *gdk_gl_context_new(GdkVisual *visual);
 GdkGLContext *gdk_gl_context_share_new(GdkVisual *visual, GdkGLContext *sharelist, gint direct);
-
-GdkGLContext *gdk_gl_context_ref(GdkGLContext *context);
-void          gdk_gl_context_unref(GdkGLContext *context);
+GdkGLContext *gdk_gl_context_attrlist_share_new(int *attrlist, GdkGLContext *sharelist, gint direct);
 
 gint          gdk_gl_make_current(GdkDrawable *drawable, GdkGLContext *context);
 void          gdk_gl_swap_buffers(GdkDrawable *drawable);
@@ -82,11 +100,17 @@ void          gdk_gl_wait_gl(void);
 
 /* glpixmap stuff */
 
+#define GDK_TYPE_GL_PIXMAP            (gdk_gl_pixmap_get_type())
+#define GDK_GL_PIXMAP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDK_TYPE_GL_PIXMAP, GdkGLPixmap))
+#define GDK_GL_PIXMAP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDK_TYPE_GL_PIXMAP, GdkGLPixmapClass))
+#define GDK_IS_GL_PIXMAP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDK_TYPE_GL_PIXMAP))
+#define GDK_IS_GL_PIXMAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_GL_PIXMAP))
+#define GDK_GL_PIXMAP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_GL_PIXMAP, GdkGLPixmap))
+
 typedef struct _GdkGLPixmap GdkGLPixmap;
 
+GType        gdk_gl_pixmap_get_type(void);
 GdkGLPixmap *gdk_gl_pixmap_new(GdkVisual *visual, GdkPixmap *pixmap);
-GdkGLPixmap *gdk_gl_pixmap_ref(GdkGLPixmap *glpixmap);
-void         gdk_gl_pixmap_unref(GdkGLPixmap *glpixmap);
 
 gint         gdk_gl_pixmap_make_current(GdkGLPixmap *glpixmap, GdkGLContext *context);
 
@@ -95,10 +119,14 @@ gint         gdk_gl_pixmap_make_current(GdkGLPixmap *glpixmap, GdkGLContext *con
 void gdk_gl_use_gdk_font(GdkFont *font, int first, int count, int list_base);
 
 
-#ifdef __cplusplus
-}
+#ifndef GTKGL_DISABLE_DEPRECATED
+#  define gdk_gl_context_ref(context)   g_object_ref(context)
+#  define gdk_gl_context_unref(context) g_object_unref(context)
+#  define gdk_gl_pixmap_ref(pixmap)     g_object_ref(pixmap)
+#  define gdk_gl_pixmap_unref(pixmap)   g_object_unref(pixmap)
 #endif
 
+G_END_DECLS
 
 #endif /* __GDK_GL_H__ */
 
